config

package
v0.0.0-...-d4a6c04 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 22, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetDatabaseConnectionString

func GetDatabaseConnectionString() string

GetDatabaseConnectionString returns the database connection string from an environment variable

func GetJWTSecretKey

func GetJWTSecretKey() []byte

Types

type ContextKey

type ContextKey string

Define a custom type for context keys to avoid potential conflicts

const JWTAccountIDKey ContextKey = "account_id"

Constant for the account ID context key

Jump to