Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetDatabaseConnectionString ¶
func GetDatabaseConnectionString() string
GetDatabaseConnectionString returns the database connection string from an environment variable
func GetJWTSecretKey ¶
func GetJWTSecretKey() []byte
Types ¶
type ContextKey ¶
type ContextKey string
Define a custom type for context keys to avoid potential conflicts
const JWTAccountIDKey ContextKey = "account_id"
Constant for the account ID context key
Click to show internal directories.
Click to hide internal directories.